# ExpirationSource

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**brand** | **str** |  | [optional] 
**expiration_interval** | **int** |  | [optional] 
**expiration_policy** | [**ExpirationPolicy**](ExpirationPolicy.md) |  | [optional] 
**instance** | **str** |  | [optional] 
**module_id** | **str** |  | [optional] 
**set_time** | **datetime** |  | [optional] 
**source** | [**ExpirationSettingsSource**](ExpirationSettingsSource.md) |  | [optional] 
**user** | **str** |  | [optional] 

[[Back to Model list]](README.md#documentation-for-models) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to README]](README.md)


